@@ -10,7 +10,7 @@ use vars qw($VERSION $MAX_RESOLVE_COUNT $LWP_TIMEOUT);
 $MAX_RESOLVE_COUNT = 4; # XXX could make both of these config options
 $LWP_TIMEOUT = 5;
 
-$VERSION = 0.22;
+$VERSION = 0.23;
 
 my $IP_RE= qr/^[0-9]+(\.[0-9]+){3}$/;
 my $HEX_IP_RE= qr/^(0x[a-f0-9]{2}|[0-9]+)(\.0x[a-f0-9]{2}|\.[0-9]+){3}$/i;
@@ -276,7 +276,7 @@ sub _spamcop_uri {
 
   # URI doesn't always put the port in the right place
   # so we strip it off here
-  $url{host} =~ s/:[0-9]+$// if $url{host};
+  $url{host} =~ s/:[0-9]*$// if $url{host};
 
 
   # Cleanup for urls that come in with a dot in the front
